@@ -48,16 +48,18 @@ def pdf2svg(fin, fout, page_no=None):
             page_no = str(page_no)
         cmd += ['-f', str(page_no), '-l', str(page_no)]
 
-    # print(" ".join(cmd))
     execute_command(cmd)
 
 
-def pdf2png(fin, fout=None):
+def pdf2png(fin, fout=None, scale_to=None):
     if fout is None:
         fout = fin[:-4] + ".png"
     fout = fout[:-4]
     cmd = f"pdftocairo -png -singlefile {fin} {fout}"
+    if scale_to is not None:
+        cmd += f" -scale-to {scale_to}"
     execute_command(cmd.split())
+    return fout + ".png"
 
 
 def pdfcrop(fin, fout=None):
@@ -69,6 +71,7 @@ def pdfcrop(fin, fout=None):
 
 
 def svg_edit_to_importable(svg_edit_file,verbose=False, keep_background_layer=True):
+    assert False
     """
     Take an inkscape file as input and split it into layers.
     CODE NOT IN USE RIGHT NOW; MUST WORK OUT WHAT TO USE IT FOR.
